import React, {
  useEffect,
  useRef,
  useState,
} from 'react';

import { connect } from 'react-redux';
import { matchRoutes } from 'react-router-config';
import {
  Link,
  useHistory,
} from 'react-router-dom';

import { MenuFoldOutlined } from '@ant-design/icons';
import ProLayout, { SettingDrawer } from '@ant-design/pro-layout';

import RightContent from '../components/GlobalHeader/RightContent';
import { Panel } from '../components/SliderPanel';
import SecurityLayout from './SecurityLayout';
import styles from './UserLayout.less';

const renderIcon = (icon, size) => {
  return (
    <img
      src={`https://panda-water.cn/web4/${icon}`}
      style={{ width: `${size}px`, height: `${size}px`, opacity: '0.8' }}
    />
  );
};
const menuExtraRender = currentRoutes => {
  const [toggleSystem, setToggleSystem] = useState(false);
  return {
    render: ({ collapsed }) => {
      if (currentRoutes) {
        return (
          <a style={{ display: 'flex', alignItems: 'center' }}>
            <img
              src={`http://panda-water.cn/web4/${currentRoutes &&
                currentRoutes.extData.icon}`}
              style={{ width: '20px', height: '20px' }}
            />
            <span
              style={{
                margin: '0 10px',
                textOverflow: 'ellipsis',
                overflow: 'hidden',
                whiteSpace: 'nowrap',
              }}
            >
              {currentRoutes && currentRoutes.name}
            </span>
            <MenuFoldOutlined onClick={() => setToggleSystem(!toggleSystem)} />
          </a>
        );
      }
      return null;
    },
    toggleSystem,
    onClose: () => setToggleSystem(!toggleSystem),
  };
  return;
};

const renderTitle = title => {
  return <span className={styles['header-title']}>{title}</span>;
};
const BasicLayout = props => {
  /* eslint-disable no-unused-vars */
  const history = useHistory();
  const [pathname, setPathname] = useState('/welcome');
  const [currentRoutes, setCurrentRoutes] = useState(props.route.routes[0]);
  const [currentIndex, setCurrentIndex] = useState(0);
  const [selectedKeys, setSelectedKeys] = useState([]);
  const [collapse, setCollapse] = useState(false);
  const [loading, setLoading] = useState(true);
  const menuDataRef = useRef([]);
  const microApp = useRef(null);
  const handleMenuCollapse = collapse => {
    setCollapse(collapse);
  };

  matchRoutes(props.route.routes, props.location.pathname);
  const extraRender = menuExtraRender(currentRoutes);
  let clearTime = null;
  useEffect(() => {
    setLoading(true);
    clearTime = setTimeout(() => {
      setCurrentRoutes(props.route.routes[currentIndex]);
      setLoading(false);
    }, 100);
    return () => clearTimeout && clearTimeout(clearTime);
  }, [currentIndex]);
  const updateSettings = config => {
    console.log(config);
  };

  const handleSelectedKey = key => {
    setSelectedKeys(`${key}`);
    extraRender.onClose();
    history.push(key);
  };

  const handleLogo = event => {
    setTimeout(() => {
      history.replace('/civbase/industry');
    }, 300);
    //
  };
  return (
    <SecurityLayout>
      <ProLayout
        logo="http://panda-water.cn/web4/assets/images/logo/单独图案-白色.svg"
        siderWidth="145px"
        title=""
        fixSiderbar={true}
        onMenuHeaderClick={event => handleLogo(event)}
        onCollapse={collapse => handleMenuCollapse(collapse)}
        menuExtraRender={extraRender.render}
        rightContentRender={() => <RightContent />}
        headerContentRender={() => renderTitle(props.global.title)}
        location={{
          pathname,
        }}
        menu={{
          loading,
        }}
        locale={true}
        menuDataRender={() => currentRoutes && currentRoutes.routes}
        menuItemRender={(menuItemProps, defaultDom) => {
          if (menuItemProps.isUrl || !menuItemProps.path) {
            return defaultDom;
          }
          return (
            <Link to={menuItemProps.path}>
              {renderIcon(
                menuItemProps.extData && menuItemProps.extData.icon,
                17,
              )}
              {defaultDom}
            </Link>
          );
        }}
        subMenuItemRender={(menuItemProps, defaultDom) => {
          return (
            <>
              {renderIcon(
                menuItemProps.extData && menuItemProps.extData.icon,
                17,
              )}
              {collapse ? (
                <div className={`ant-pro-menu-item ${styles.shortName}`}>
                  {menuItemProps.extData.shortName}
                </div>
              ) : (
                defaultDom
              )}
            </>
          );
        }}
        menuProps={{
          onClick: ({ item, key, keyPath, domEvent }) => {
            setSelectedKeys(`${key}`);
            window.share.event.emit('changeRoute', key);
          },
          selectedKeys: [selectedKeys],
        }}
        postMenuData={menuData => {
          menuDataRef.current = menuData || [];
          return menuData || [];
        }}
        {...props}
      >
        {/* {renderRoutes(props.route.routes)} */}
        <Panel
          visible={extraRender.toggleSystem}
          keyboard={true}
          onClose={extraRender.onClose}
          data={props.route.routes || []}
          onChange={index => setCurrentIndex(index)}
          onSelect={selectKeys => handleSelectedKey(selectKeys)}
        />
        <div
          id="subapp-container"
          className="subapp-container"
          ref={microApp}
        />
        <SettingDrawer onSettingChange={config => updateSettings(config)} />
      </ProLayout>
    </SecurityLayout>
  );
};
const mapStateToProps = state => {
  return {
    global: state.getIn(['global', 'globalConfig']),
  };
};
export default connect(
  mapStateToProps,
  null,
)(BasicLayout);
